@@ -14,7 +14,7 @@ import os, shutil, string, sys, time
 class Mooi:
 	DIR = os.path.expandvars('${HOME}/Lavengro')
 	LRC = os.path.expandvars(DIR + os.sep + 'lavengrorc')
-	HDR = "\nLavengro - The Word Master - Ver. 1.1.7\n" +\
+	HDR = "\nLavengro - The Word Master\n" +\
 		  "-- Enter 'q' at any time to quit --\n"
 	SUB =  "(Available subjects) - 'q' to quit"
 	MODE = ['lavengro - programmed learning',
@@ -116,7 +116,7 @@ class Mooi:
 					tokens = string.split(entry,':')
 					self.tests.remove(tokens[0])
 					if ((tokens[1].find('*SCORE*') != -1) and
-						(float(tokens[2]) > 89.0)):
+						(float(tokens[2]) >= 90.0)):
 						continue
 					tests.append(tokens[0])
 					if (i < 2):
@@ -153,7 +153,6 @@ class Mooi:
 		# choose test in subject
 		self.tests = []
 		files = os.listdir(self.DIR + os.sep + subdir)
-		files.sort()
 		for file in files:
 			if (not os.path.isdir(self.DIR + os.sep + subdir + os.sep + file)):
 				# no backups, *MEs, .lavs, or bsd indices
@@ -163,8 +162,7 @@ class Mooi:
 					(string.find(file,'index') == -1)):
 					self.tests.append(file)
  		if (len(self.tests) == 0):
-			print 'No tests for chosen subject.\nExiting...'
-			sys.exit(1)
+			self.exit('No tests for chosen subject.\nExiting...', 1)
 
 		self.prefix = self.DIR + os.sep + subdir + os.sep
 		self.tests.sort(self.compDates)
@@ -184,7 +182,7 @@ class Mooi:
 			if not self.lavLoaded:
 				self.loadLav()
 				self.lavLoaded = 1
-				self.tests.sort()
+			self.tests.sort()
 			choice = self.query(self.tests, 'Enter quiz number: ')
 			self.quiz = [ self.prefix + self.tests[choice], 0, 1]
 		return
@@ -245,39 +243,42 @@ class Mooi:
 
 	# open the chosen quiz and pull question and answer fields
 	def loadQuiz(self, data):
-		while (len(data) > 0):
-			data.pop()
-		f = open(self.quiz[0],'r')
-		lines = f.readlines()
-		f.close()
-		lines = self.purge(lines)
-		lines2 = []
-		tmpline = ''
-		# get test title if exists
-		if ( (lines[0])[0] == '#'):
-			title = string.strip(lines[0])
-			title = string.strip(string.replace(title,'#',''))
-			print '\nCurrent test: ' + title
-		# cat '\' continued lines
-		for line in lines:
-			if (line[0] == '#'):
-				continue	
-			line = string.strip(line)
-			tmplist = list(line)
-			tmpline = tmpline + line
-			if (tmplist[-1] != '\\'):
-				lines2.append(tmpline)
-				tmpline = ''
-			else:
-				tmpline = string.replace(tmpline,'\\','')
-		# create list of entries
-		for line in lines2:
-			entry = []
-			tokens = string.split(line,':')
-			entry.append(string.strip(tokens[self.quiz[1]]))
-			entry.append(string.strip(tokens[self.quiz[2]]))
-			data.append(entry)
-			self.total = len(data)
+		try:
+			while (len(data) > 0):
+				data.pop()
+			f = open(self.quiz[0],'r')
+			lines = f.readlines()
+			f.close()
+			lines = self.purge(lines)
+			lines2 = []
+			tmpline = ''
+			# get test title if exists
+			if ( (lines[0])[0] == '#'):
+				title = string.strip(lines[0])
+				title = string.strip(string.replace(title,'#',''))
+				print '\nCurrent test: ' + title
+			# cat '\' continued lines
+			for line in lines:
+				if (line[0] == '#'):
+					continue	
+				line = string.strip(line)
+				tmplist = list(line)
+				tmpline = tmpline + line
+				if (tmplist[-1] != '\\'):
+					lines2.append(tmpline)
+					tmpline = ''
+				else:
+					tmpline = string.replace(tmpline,'\\','')
+			# create list of entries
+			for line in lines2:
+				entry = []
+				tokens = string.split(line,':')
+				entry.append(string.strip(tokens[self.quiz[1]]))
+				entry.append(string.strip(tokens[self.quiz[2]]))
+				data.append(entry)
+				self.total = len(data)
+		except:
+			self.exit('Failure to load test.\nExiting...', 1)
 		return
 
 	### ----- Public Interface ----- ###
